#!/bin/sh
#****************************************************************************
#
#   MODULE              inst_knlsync.sh
#
#   DESCRIPTION         Installer for the kernel sync app.
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2024
#   ALL RIGHTS RESERVED.
#
#
#*****************************************************************************

#Uninstall Requested
if [ $# -ne 0 ]; then
  if [ "$1" = "-u" ]; then
    rm -f /etc/systemd/system/attoknlsync.service
    rm -f /home/admin/apps/knlsync_app.elf
    rm -f /etc/attoversions/knlsync_app.vsn
    systemctl daemon-reload
    exit 0
  fi
fi

echo '[Unit]' > a.sv
echo 'Description=Sync Kernel' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
echo 'Type=oneshot' >> a.sv
echo '# Wait 30 seconds before the unit starts.' >> a.sv
echo 'ExecStartPre=/bin/sleep 30' >> a.sv
echo 'ExecStart=/home/admin/apps/knlsync_app.elf' >> a.sv
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

#
# If the service doesn't currently exist, request a reboot
#
if [ ! -e /etc/systemd/system/attoknlsync.service ]
then
   echo "Setting reboot request flag from knlsync_app installer"
   touch /var/tmp/reboot_required
fi

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/attoknlsync.service
chmod 644 /etc/systemd/system/attoknlsync.service

#
# Now reload systemd with the knlsync app
#
systemctl daemon-reload
systemctl enable --no-block attoknlsync.service
