#!/bin/sh
#****************************************************************************
#
#   MODULE              inst_notify_app.sh
#
#   DESCRIPTION         Installer for the notify app.
#
#   
#
#   THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
#   ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
#   WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
#   PURSUANT TO WHICH IT WAS FURNISHED.
#
#   COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2025
#   ALL RIGHTS RESERVED.
#
#   Arguments: -u indicates uninstall this app
#
#*****************************************************************************

#Uninstall  Requested
if [ $# -ne 0 ]; then
  if [ "$1" = "-u" ]; then
    systemctl disable attonotify.service
    #delete all components
    rm -f /etc/systemd/system/attonotify.service
    rm -f /home/admin/apps/notify_app.elf
    systemctl daemon-reload
    exit 0
  fi
fi

# Disable the attonetmon service
systemctl disable attonotify.service

# Create the service file locally, then copy to systemd directory.
# Create the service file locally, then copy to systemd directory.
echo '[Unit]' > a.sv
echo 'Description=ATTO Notify Application' >> a.sv
echo 'After=attomapping.service' >> a.sv
echo 'Requires=attomapping.service' >> a.sv
echo >> a.sv
echo '[Service]' >> a.sv
# All services need the folowing:
echo 'WorkingDirectory=/home/admin/apps' >> a.sv
echo 'ExecStart=/home/admin/apps/notify_app.elf' >> a.sv
echo 'Type=simple' >> a.sv # Process starts and does not exit. 
echo 'Restart=always' >> a.sv # Always, so don't forget RestartSec.

# Settings for User, StdOut/StdErr vary from service to service:
echo 'User=admin' >> a.sv
echo 'StandardOutput=kmsg+console' >> a.sv
echo 'StandardError=kmsg+console' >> a.sv
echo 'ExecStartPre=-/bin/dmesg -n 1' >> a.sv
echo 'ExecStartPre=/bin/sleep 3' >> a.sv
echo 'RestartSec=5' >> a.sv
echo 'LimitCORE=1048576:1048576' >> a.sv
echo 'TimeoutStopSec=5' >> a.sv
echo >> a.sv
echo '[Install]' >> a.sv
echo 'WantedBy=multi-user.target' >> a.sv

#
# If the service doesn't currently exist, request a reboot
#
if [ ! -e /etc/systemd/system/attonotify.service ]
then
   echo "Setting reboot request flag from notify app installer"
   touch /var/tmp/reboot_required
fi

#
# Copy a.sv to the systemd directory.
#
mv a.sv /etc/systemd/system/attonotify.service
chmod 644 /etc/systemd/system/attonotify.service

#
# Now reload systemd with the netmon app
#
systemctl daemon-reload
systemctl enable attonotify.service
